==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/ClientDetailDialog.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef CLIENTDETAILDLG_H
#define CLIENTDETAILDLG_H

#include <wx/dialog.h>                      // Needed for wxDialog

class CUpDownClient;

class CClientDetailDialog : public wxDialog
{
public:
        CClientDetailDialog(wxWindow*parent,CUpDownClient* client);   // standard constructor
        void Localize();
        virtual ~CClientDetailDialog();
        virtual bool OnInitDialog();
// Dialog Data
        enum
        {
            IDD_SOURCEDETAILWND,
            IDD = IDD_SOURCEDETAILWND
        };

protected:
          void OnBnClose(wxCommandEvent& evt);

          DECLARE_EVENT_TABLE()

private:
        CUpDownClient* m_client;
};
#endif

==> xmule-1.10.0.tar.bz2: xmule-1.10.0/src/ClientDetailDialog.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef CLIENTDETAILDLG_H
#define CLIENTDETAILDLG_H

#include "resource.h"                       // Needed for IDD_SOURCEDETAILWND - audited 4 Nov 2004

#include <stdint.h>                         // Needed for uint16_t
#include <wx/dialog.h>                      // Needed for wxDialog

class CUpDownClient;

class CClientDetailDialog : public wxDialog
{
public:
    CClientDetailDialog(wxWindow* parent, CUpDownClient* client);   // standard constructor
    void Localize();
    virtual ~CClientDetailDialog();
    virtual bool OnInitDialog();
// Dialog Data
enum { IDD = IDD_SOURCEDETAILWND };

protected:
    void OnBnClose(wxCommandEvent& evt);
    DECLARE_EVENT_TABLE()

private:
    CUpDownClient* m_client;
};

#endif
